summaryrefslogtreecommitdiff
path: root/qadevOOo/tests/java/mod/_sc/ScTableRowObj.java
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-06-08 14:06:08 +0200
committerNoel Grandin <noel@peralex.com>2015-06-08 14:06:54 +0200
commitb9dd51782ceba70bda091191349d31767b7bf744 (patch)
treeb08a32be30934595e9bdcf98e877f16a3d170e68 /qadevOOo/tests/java/mod/_sc/ScTableRowObj.java
parentc1692f620610621a139e54fb1f9d11d4c177608d (diff)
some spelling fixes, mostly in Java code
Change-Id: Ib9d0522a1f371404ee990348712e2d196049f69f
Diffstat (limited to 'qadevOOo/tests/java/mod/_sc/ScTableRowObj.java')
-rw-r--r--qadevOOo/tests/java/mod/_sc/ScTableRowObj.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/qadevOOo/tests/java/mod/_sc/ScTableRowObj.java b/qadevOOo/tests/java/mod/_sc/ScTableRowObj.java
index 0a4fe2dd5ccc..ca2055ec94f7 100644
--- a/qadevOOo/tests/java/mod/_sc/ScTableRowObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScTableRowObj.java
@@ -87,7 +87,7 @@ public class ScTableRowObj extends TestCase {
}
/**
* Creating a Testenvironment for the interfaces to be tested.
* Retrieves a collection of spreadsheets from the document and takes one of
* them. Obtains the collection of rows using the interface
* <code>XColumnRowRange</code>. Obtains the row with index 6 from the
@@ -126,19 +126,19 @@ public class ScTableRowObj extends TestCase {
} catch(com.sun.star.lang.WrappedTargetException e) {
e.printStackTrace(log);
throw new StatusException(
- "Exception during creating Testenvironment", e);
+ "Exception during creating TestEnvironment", e);
} catch(com.sun.star.container.NoSuchElementException e) {
e.printStackTrace(log);
throw new StatusException(
- "Exception during creating Testenvironment", e);
+ "Exception during creating TestEnvironment", e);
} catch(com.sun.star.lang.IndexOutOfBoundsException e) {
e.printStackTrace(log);
throw new StatusException(
- "Exception during creating Testenvironment", e);
+ "Exception during creating TestEnvironment", e);
} catch(com.sun.star.lang.IllegalArgumentException e) {
e.printStackTrace(log);
throw new StatusException(
- "Exception during creating Testenvironment", e);
+ "Exception during creating TestEnvironment", e);
}
log.println("creating a new environment for object");
@@ -87,7 +87,7 @@ public class ScTableRowObj extends TestCase {
}
/**
- * Creating a Testenvironment for the interfaces to be tested.
+ * Creating a TestEnvironment for the interfaces to be tested.
* Retrieves a collection of spreadsheets from the document and takes one of
* them. Obtains the collection of rows using the interface